==> deepin-log-viewer_5.9.7+ds1.orig.tar.xz: deepin-log-viewer-5.9.7/translations/deepin-log-viewer_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Показать в файловом менеджере</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Очистить журнал</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Вы уверены, что хотите очистить журнал?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Подтвердить</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Все</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Сегодня</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 дня</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 неделя</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 месяц</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 месяца</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Экспорт</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Экспорт</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Все</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Экстренно</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Тревога</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Критическая ошибка</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Уведомление</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Информация</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Отладка</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Вход</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Загрузка</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Выключение</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Trace</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>Текст (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Экспортирование...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Экспортирование прошло успешно</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Экспорт Файла</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Период:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Уровень:</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Список приложений:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Состояние:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Тип События:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Пользователь:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Действие:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Имя пользователя:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Запись о включении</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Запись о выключении</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Запись об авторизации</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Отладка</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Информация</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Экстренно</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Тревога</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Критическая ошибка</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Уведомление</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Super critical</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Файл журнала пустой</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Просмотрщик Журнала</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Просмотрщик журнала - это полезный инструмент для просмотра системных журналов.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Поиск не дал результатов</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Уровень</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Процесс</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Дата и Время</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Информация</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Пользователь</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Источник</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Действие</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Состояние</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Тип события</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Имя пользователя</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Уровень:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Процесс:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Дата и Время:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Информация:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Ничего</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Пользователь:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Дата и время</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Системный Журнал</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Журнал Ядра</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Журнал Загрузки</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Журнал dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Журнал Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Журнал Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Журнал Приложения</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Событие запуска-выключения</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.5.8+ds1.orig.tar.xz: deepin-log-viewer-6.5.8/translations/deepin-log-viewer_ru.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Показать в файловом менеджере</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Очистить журнал</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Вы уверены, что хотите очистить журнал?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Подтвердить</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Все</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Сегодня</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 дня</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 неделя</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 месяц</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 месяца</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Экспорт</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Все</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Экстренно</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Тревога</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Критическая ошибка</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Уведомление</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Информация</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Отладка</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Вход</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Загрузка</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Выключение</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Сверхкритичное</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Трассировка</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remote</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Document audit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>Текст (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Экспортирование...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Экспортирование прошло успешно</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Ошибка экспорта</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Экспорт Файла</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Период:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Уровень:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Состояние:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Тип События:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Пользователь:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Действие:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Имя пользователя:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Запись о включении</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Запись о выключении</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Запись об авторизации</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Application:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submodule:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Отладка</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Информация</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Экстренно</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Тревога</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Критическая ошибка</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Уведомление</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Трассировка</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Сверхкритичное</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Файл журнала пустой</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Просмотрщик Журнала</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Просмотрщик журнала - это полезный инструмент для просмотра системных журналов.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Поиск не дал результатов</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Уровень</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Процесс</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Дата и Время</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Информация</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Пользователь</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Источник</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Действие</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Состояние</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Тип события</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Имя пользователя</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Уровень:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Процесс:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Дата и Время:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Информация:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Ничего</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Пользователь:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time Modified</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SIG</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EXE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Core File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User Name </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Offset</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Дата и время</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Системный Журнал</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Журнал Ядра</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Журнал Загрузки</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Журнал dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Журнал Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Журнал Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Журнал Приложения</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Событие запуска-выключения</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Журнал dnf</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Custom Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audit Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PATH</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PERIOD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>LEVEL</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Период обновления</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 с</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 мин</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Не обновлять</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Экспорт всех</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Обновить</translation>
    </message>
</context>
</TS>
